@@ -20,6 +20,7 @@
 #include <sys/xattr.h>
 #include <vector>
 #include <stdlib.h>
+#include <limits.h>
 
 #ifdef __APPLE__
     #include <sys/param.h>
@@ -1412,6 +1413,7 @@ fs_napi(Napi::Env env, Napi::Object exports)
     exports_fs["S_IFLNK"] = Napi::Number::New(env, S_IFLNK);
     exports_fs["DT_DIR"] = Napi::Number::New(env, DT_DIR);
     exports_fs["DT_LNK"] = Napi::Number::New(env, DT_LNK);
+    exports_fs["PLATFORM_IOV_MAX"] = Napi::Number::New(env, IOV_MAX);
 
     exports_fs["set_debug_level"] = Napi::Function::New(env, set_debug_level);
 
