@@ -2,7 +2,7 @@
     typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
     typeof define === 'function' && define.amd ? define(factory) :
     (global = typeof globalThis !== 'undefined' ? globalThis : global || self, (global.date = global.date || {}, global.date.locale = global.date.locale || {}, global.date.locale.uz = factory()));
-}(this, (function () { 'use strict';
+})(this, (function () { 'use strict';
 
     /**
      * @preserve date-and-time.js locale configuration
@@ -27,4 +27,4 @@
 
     return uz;
 
-})));
+}));
